@@ -1,5 +1,6 @@
 from email.Utils import parsedate,parsedate_tz,mktime_tz,parseaddr,make_msgid, formataddr
 from time import ctime,time
+import gtk
 import email
 import email.Header
 from StringIO import *
@@ -46,8 +47,13 @@ class Article:
                 charset=self.fallback_cset
             try:
                 header_decoded=header_decoded+" "+unicode(parts[i][0],charset,"replace").strip(" ")
-            except LookupError:
-                header_decoded=header_decoded+" "+unicode(parts[i][0],self.fallback_cset,"replace").strip(" ")
+            except :#LookupError: 
+                # had to comment the LookupError and add a second except to catch an exception that popped up
+                # trying to reopen an article with some encoded words in the xface ...
+                try:
+                    header_decoded=header_decoded+" "+unicode(parts[i][0],self.fallback_cset,"replace").strip(" ")
+                except TypeError:
+                    header_decoded=header_decoded+" "+parts[i][0].strip()
         header_decoded=header_decoded.strip()
         return header_decoded
 
@@ -58,7 +64,7 @@ class Article:
             decoded_list=[unicode(line,self.fallback_cset,"replace") for line in list]
         self.raw_header_list=decoded_list
         
-    def parse_header_list(self,hlist):
+    def parse_header_list(self,hlist,rebuild=False):
         i=0
         hlist_len=len(hlist)
         while i < hlist_len:
@@ -83,7 +89,7 @@ class Article:
         self.email=email
         self.from_name=self.hdict.get("from","")
         self.ngroups=self.hdict.get("newsgroups","")
-        self.ref=self.hdict.get("references","")
+        #self.ref=self.hdict.get("references","")  # I don't want to update this field
         self.fup_to=self.hdict.get("followup-to","")
         self.reply_to=self.hdict.get("reply-to","")
         self.user_agent=self.hdict.get("user-agent","")
@@ -97,7 +103,10 @@ class Article:
         self.cset=ctype_dict.get("charset","")
         if self.cset=="":
             self.cset=self.fallback_cset
-        self.decode_header_list(hlist)
+        if not rebuild:
+            self.decode_header_list(hlist)
+        else:
+            self.raw_header_list=hlist
 
     def get_hdr(self,name):
         name=name.lower()
@@ -153,8 +162,10 @@ class Article:
 
     def get_body(self):
         return self.body
-
-    def set_body(self,list,rawbody):
+        
+    def set_body(self,rawbody,rebuild=False):
+        if rebuild: rawbody=rawbody.encode("utf-8")
+        self.raw_body=rawbody
         msg = email.message_from_string(rawbody)
         charsets= msg.get_charsets()
         if msg.is_multipart():
@@ -167,17 +178,19 @@ class Article:
                 ctype = part.get_content_type()
                 # Skip multipart container
                 if mtype != 'multipart':
-                    payload=part.get_payload(decode=(mtype=='text'))    
+                    payload=part.get_payload(decode=(mtype=='text'))
+                    
                     if type(payload)==type([]):
                         try: body=payload[0].as_string()
                         except: body=str(payload[0])
                     else:
                         body=str(payload)
                     body = body +'\n'
-                    try:
-                        body = unicode(body, str(charsets[i]), 'replace')
-                    except LookupError:
-                        body = unicode(body, self.fallback_cset, 'replace')
+                    if not rebuild:
+                        try:
+                            body = unicode(body, str(charsets[i]), 'replace')
+                        except LookupError:
+                            body = unicode(body, self.fallback_cset, 'replace')
                     body_list.append(body)
                     self.body_parts.append((ctype,body))
                 i=i+1
@@ -185,18 +198,29 @@ class Article:
             body='\n'.join(body_list)
             self.body= body.splitlines()
         else:
-            body=msg.get_payload(decode=True)
-            try:
-                body = unicode(body, self.cset, 'replace')
-            except LookupError:
-                body = unicode(body, self.fallback_cset, 'replace')
+            
+            body=msg.get_payload(decode=False) #the q-printable could break if I'm reloading the article
+            
+            if not rebuild:
+                body=msg.get_payload(decode=True)
+                try:
+                    body = unicode(body, self.cset, 'replace')
+                except LookupError:
+                    body = unicode(body, self.fallback_cset, 'replace')
             self.body=body.splitlines()
+        self.has_body=True
 
-    def get_raw(self):
+        
+
+
+    def get_raw(self,return_string=False):
         try:
             raw=self.raw_header_list+[""]+self.body
         except:
             raw=None
+        if return_string:
+            if raw: raw="\n".join(raw)
+            else :  raw=None
         return raw
 
     def set_score(self,score):
@@ -208,52 +232,182 @@ class Article:
     def reset_article_score_actions(self):
         self.score=0
         self.marked_for_download=False
-        self.keep=0
-        self.watch=False
-        self.ignore=False
-        self.fg_color=None
-        self.bg_color=None
-
-    def __init__(self,number,msgid,from_name,ref,subj,date,fallback_charset,original_group,xref,bytes,lines):
-        self.hdict=dict()
-        self.score=0
-        self.number=number
-        self.fallback_cset=fallback_charset
-        self.msgid=msgid
-        self.from_name=self.my_decode_header(from_name)
-        self.nick,self.email=self.parse_from(self.from_name)
-        self.ref=self.my_decode_header(ref)
-        self.subj=self.my_decode_header(subj)
-        self.date=date
-        self.date_parsed=self.parse_date(date)
-        self.hdict["message-id"]=msgid
-        self.hdict["from"]=self.my_decode_header(from_name)
-        self.hdict["references"]=self.my_decode_header(ref)
-        self.hdict["subject"]=self.my_decode_header(subj)
-        self.hdict["date"]=date
-        self.hdict["xref"]=xref[5:].strip()
-        self.hdict["bytes"]=bytes
-        self.hdict["lines"]=lines
-
-        self.body=None
-        self.raw=None
-        self.is_read=False
-        self.marked_for_download=False
         self.keep=False
         self.watch=False
         self.ignore=False
-        self.original_group=original_group
-        self.x_face=None
-        self.face=None
-        self.raw_header_list=None
         self.fg_color=None
         self.bg_color=None
-        self.xref=xref
-        try: self.bytes=int(bytes)
-        except ValueError: self.bytes=0
-        try: self.lines=int(lines)
-        except ValueError: self.lines=0
 
+    def get_article_info(self,icons):
+        art_fup,art_body,art_unread,art_read,art_mark,art_keep,art_unkeep,art_watch,art_unwatchignore,art_ignore=icons
+            
+            
+        #number=self.number
+        msgid=self.msgid
+        nick,from_name,ref,subj,date,date_parsed=self.get_headers()
+        if self.keep:
+            icon2=art_keep
+        else:
+            icon2=art_unkeep
+
+        if self.is_read:
+            isUnread=False
+            icon=art_read
+        else:
+            isUnread=True
+            if self.has_body:
+                icon=art_body
+            elif self.marked_for_download:
+                icon=art_mark
+            else:
+                icon=art_unread
+            
+        show_score=True          
+        if self.score<0:
+            score_foreground="red"
+                
+        elif self.score>0:
+            score_foreground="darkgreen"
+           
+        else : #self.score==0
+            score_foreground="darkgreen"
+            show_score=False
+
+           
+        if self.watch:
+            icon3=art_watch
+        elif self.ignore:
+            icon3=art_ignore
+        else:
+            icon3=art_unwatchignore
+        
+        try :
+            fg_color=self.fg_color
+        except:
+            fg_color_set=False
+            fg_color="black"
+        else:
+            if fg_color:
+                if self.fg_color.lower()!="default":
+                    fg_color_set=True
+                    try: gtk.gdk.color_parse(fg_color)
+                    except: 
+                        fg_color="black"
+                        fg_color_set=False
+                else:
+                    fg_color_set=False
+                    fg_color="black"
+            else:
+                fg_color_set=False
+                fg_color="black"
+
+
+        try :
+            bg_color=self.bg_color
+        except:
+            bg_color_set=False
+            bg_color="white"
+        else:
+            if bg_color:
+                if self.bg_color.lower()!="default":
+                    bg_color_set=True
+                    try: gtk.gdk.color_parse(bg_color)
+                    except: 
+                        bg_color="white"
+                        bg_color_set=False
+                else:
+                    bg_color_set=False
+                    bg_color="black"                           
+            else:
+                bg_color_set=False
+                bg_color="white"
+        article_info = [icon,subj,nick,date_parsed,self,isUnread,self.secs,self.score,score_foreground,show_score,icon2,icon3,0,False,fg_color_set,fg_color,bg_color_set,bg_color,False,0]
+        return article_info
+
+
+    def __init__(self,number,msgid,from_name,ref,subj,date,fallback_charset,original_group,xref,bytes,lines,rebuild=False):
+        if not rebuild:
+            self.hdict=dict()
+            self.score=0
+            self.number=number
+            self.fallback_cset=fallback_charset
+            self.msgid=self.my_decode_header(msgid)
+            self.from_name=self.my_decode_header(from_name)
+            self.nick,self.email=self.parse_from(self.from_name)
+            self.ref=self.my_decode_header(ref)
+            self.subj=self.my_decode_header(subj)
+            self.date=date
+            self.date_parsed=self.parse_date(date)
+            self.hdict["message-id"]=msgid
+            self.hdict["from"]=self.my_decode_header(from_name)
+            self.hdict["references"]=self.my_decode_header(ref)
+            self.hdict["subject"]=self.my_decode_header(subj)
+            self.hdict["date"]=date
+            self.hdict["xref"]=xref[5:].strip()
+            self.hdict["bytes"]=bytes
+            self.hdict["lines"]=lines
+
+            self.body=None
+            self.raw=None
+            self.is_read=False
+            self.marked_for_download=False
+            self.keep=False
+            self.watch=False
+            self.ignore=False
+            self.original_group=original_group
+            self.x_face=None
+            self.face=None
+            self.raw_header_list=None
+            self.fg_color=None
+            self.bg_color=None
+            self.xref=self.hdict.get("xref","")
+            self.raw_body=""
+            self.has_body=False
+            try: self.bytes=int(bytes)
+            except ValueError: self.bytes=0
+            try: self.lines=int(lines)
+            except ValueError: self.lines=0
+        else:
+            self.hdict=dict()
+            self.score=0
+            self.number=number
+            self.fallback_cset=fallback_charset
+            self.msgid=msgid
+            self.from_name=from_name
+            self.nick,self.email=self.parse_from(self.from_name)
+            self.ref=ref
+            self.subj=subj
+            self.date=date
+            self.date_parsed=self.parse_date(date)
+            self.hdict["message-id"]=msgid
+            self.hdict["from"]=self.from_name
+            self.hdict["references"]=self.ref
+            self.hdict["subject"]=self.subj
+            self.hdict["date"]=date
+            self.hdict["xref"]=xref
+            self.hdict["bytes"]=bytes
+            self.hdict["lines"]=lines
+            self.body=None
+            self.raw=None
+            self.is_read=False
+            self.marked_for_download=False
+            self.keep=False
+            self.watch=False
+            self.ignore=False
+            self.original_group=original_group
+            self.x_face=None
+            self.face=None
+            self.raw_header_list=None
+            self.fg_color=None
+            self.bg_color=None
+            self.xref=self.hdict.get("xref","")
+            self.raw_body=""
+            self.has_body=False
+            try: self.bytes=int(bytes)
+            except ValueError: self.bytes=0
+            try: self.lines=int(lines)
+            except ValueError: self.lines=0
+        
 class Article_To_Send:
     def best_enc(self,text):
         for best_enc in self.ordered_list:
