@@ -155,6 +155,7 @@ class Config_Win:
         self.oneclick_checkbutton.set_active(configs.get("oneclick","False")=="True")
         self.advance_on_mark_checkbutton.set_active(configs.get("advance_on_mark","False")=="True")
         self.oneclick_article_checkbutton.set_active(configs.get("oneclick_article","False")=="True")
+        self.expand_groups_checkbutton.set_active(configs.get("expand_group","False")=="True")
         self.one_key_spin.set_value(int(configs["scroll_fraction"]))
         self.sort_order_checkbutton.set_active(configs.get("ascend_order","False")=="True")
         self.sort_combo.child.set_text(configs["sort_col"].encode("utf-8").capitalize())
@@ -168,19 +169,18 @@ class Config_Win:
             self.browser_checkbutton.set_active(False)
             self.browser_entry.set_sensitive(False)
 
-        if configs["external_editor"]=="True":
-            self.editor_checkbutton.set_active(True)
-        else:
-            self.editor_checkbutton.set_active(False)
+      
+            
+        self.editor_checkbutton.set_active(eval(configs["external_editor"]))
         self.editor_entry.set_text(configs["editor_launcher"].encode("utf-8"))
 
         self.purge_read_spinbutton.set_value(int(configs["purge_read"]))
         self.purge_unread_spinbutton.set_value(int(configs["purge_unread"]))
 
-        if configs["download_bodies"]=="True":
-            self.download_bodies_checkbutton.set_active(True)
-        else:
-            self.download_bodies_checkbutton.set_active(False)
+        
+            
+        self.download_bodies_checkbutton.set_active(eval(configs["download_bodies"]))
+
         
         if configs["limit_articles"]=="True":
             self.limit_articles_checkbutton.set_active(True)
@@ -189,6 +189,21 @@ class Config_Win:
             self.limit_articles_spinbutton.set_sensitive(False)
 
         self.limit_articles_spinbutton.set_value(int(configs["limit_articles_number"]))
+        if configs["automatic_download"]=="True":
+            self.auto_download_checkbutton.set_active(True)
+            self.auto_download_spinbutton.set_sensitive(True)
+        else:
+            self.auto_download_spinbutton.set_sensitive(False)
+
+        self.auto_download_spinbutton.set_value(int(configs["download_timeout"]))
+        
+        try: self.configs["threading_method"]               # upgrading check 
+        except KeyError: self.config["threading_method"]=2 # upgrading check 
+        
+        if self.configs["threading_method"]=="1":
+            self.threading_method_radiobutton1.set_active(True)
+        else:
+            self.threading_method_radiobutton2.set_active(True)
         
         if self.configs["lang"]=="en":
             self.lang_en_radiobutton.set_active(True)
@@ -243,13 +258,15 @@ class Config_Win:
         conf.configs["oneclick"]=str(bool(self.oneclick_checkbutton.get_active()))
         conf.configs["advance_on_mark"]=str(bool(self.advance_on_mark_checkbutton.get_active()))
         conf.configs["oneclick_article"]=str(bool(self.oneclick_article_checkbutton.get_active()))
+        conf.configs["expand_group"]=str(bool(self.expand_groups_checkbutton.get_active()))
         conf.configs["scroll_fraction"]=repr(self.one_key_spin.get_value_as_int())
         conf.configs["sort_col"]=self.sort_combo.child.get_text().decode("utf-8")
         conf.configs["ascend_order"]=str(bool(self.sort_order_checkbutton.get_active()))
         conf.configs["fallback_charset"]=self.fallback_charset_combo.child.get_text()
 
-        if self.browser_checkbutton.get_active() and self.browser_entry.get_text().strip() and \
-           self.exists(self.browser_entry.get_text().strip()):
+#        if self.browser_checkbutton.get_active() and self.browser_entry.get_text().strip() and \
+#           self.exists(self.browser_entry.get_text().strip()):
+        if self.browser_checkbutton.get_active() and self.browser_entry.get_text().strip():
             conf.configs["custom_browser"]="True"
             conf.configs["browser_launcher"]=self.browser_entry.get_text().decode("utf-8")
         else:
@@ -267,6 +284,14 @@ class Config_Win:
         conf.configs["limit_articles"]=repr(bool(self.limit_articles_checkbutton.get_active()))
         conf.configs["limit_articles_number"]=repr(self.limit_articles_spinbutton.get_value_as_int())
 
+        conf.configs["automatic_download"]=repr(bool(self.auto_download_checkbutton.get_active()))
+        conf.configs["download_timeout"]=repr(self.auto_download_spinbutton.get_value_as_int())
+        
+        if self.threading_method_radiobutton1.get_active():
+            conf.configs["threading_method"]="1"
+        else:
+            conf.configs["threading_method"]="2"
+            
         if self.lang_en_radiobutton.get_active():
             conf.configs["lang"]="en"
         elif self.lang_it_radiobutton.get_active():
@@ -320,19 +345,7 @@ class Config_Win:
         #show thread cause possible sorting changes
         self.main_win.show_threads(self.main_win.groups_pane.get_first_selected_group())
             
-        #update_layout
-        layout_methods = {"1":self.main_win.build_layout_type_1,
-                          "2":self.main_win.build_layout_type_2,
-                          "3":self.main_win.build_layout_type_3,
-                          "4":self.main_win.build_layout_type_4
-                         }
-        r,c=divmod(int(configs["layout"])-1,6)
-        layout_builder = layout_methods.get(str(r+1), None)
-        if layout_builder: layout_builder(c+1)
-        else: self.main_win.build_layout_type_1(1)   # If there is no layout associated to
-                                            # self.configs["layout"] then build 1
-            
-        self.main_win.set_sizes()
+
 
         #update expander column
         
@@ -373,7 +386,23 @@ class Config_Win:
             else:
                 self.main_win.connectionsPool[server]=Connection(cp.get(server,"server"),cp.get(server,"port"),cp.get(server,"auth"),cp.get(server,"username"),cp.get(server,"password"))
 
-
+    def update_layout(self,obj,configs=None,layout_number=0):
+        #update_layout
+        layout_methods = {"1":self.main_win.build_layout_type_1,
+                          "2":self.main_win.build_layout_type_2,
+                          "3":self.main_win.build_layout_type_3,
+                          "4":self.main_win.build_layout_type_4
+                         }
+        if configs:
+            r,c=divmod(int(configs["layout"])-1,6)
+        else:
+            r,c=divmod(layout_number-1,6)
+        layout_builder = layout_methods.get(str(r+1), None)
+        if layout_builder: layout_builder(c+1)
+        else: self.main_win.build_layout_type_1(1)   # If there is no layout associated to
+                                            # self.configs["layout"] then build 1
+        self.main_win.set_sizes()
+        
     def change_fonts_status(self,obj):
         status=self.use_system_fonts_checkbutton.get_active()
         self.font_article_hbox.set_sensitive(not status)
@@ -418,6 +447,10 @@ class Config_Win:
         status=self.limit_articles_checkbutton.get_active()
         self.limit_articles_spinbutton.set_sensitive(status)
 
+    def change_auto_download_status(self,obj):
+        status=self.auto_download_checkbutton.get_active()
+        self.auto_download_spinbutton.set_sensitive(status)
+
     def add_tag_line(self,obj):
         tag_win=Tags_Window()
 
@@ -909,6 +942,7 @@ class Config_Win:
             layout_image=gtk.Image()
             layout_image.set_from_file("pixmaps/layout_"+str(i+1)+".xpm")
             rbutton.add(layout_image)
+            rbutton.connect("clicked",self.update_layout,None,i+1)
             self.layout_radiobuttons.append(rbutton)
             r,c=divmod(i,6)
             layouts_table.attach(rbutton,r,r+1,c,c+1,gtk.FILL,gtk.FILL,12,4)
@@ -976,36 +1010,16 @@ class Config_Win:
 
     def build_groups_page(self):
         notebook=gtk.Notebook()
-        label_groups=gtk.Label("<b>"+_("Groups Properties")+"</b>")
-        label_groups.set_use_markup(True)
-
-        groups_vbox=gtk.VBox()
-
-        sort_main_vbox=gtk.VBox()
-        sort_main_vbox.set_border_width(4)
-        sort_main_label=gtk.Label("<b>"+_("Sorting Options")+"</b>")
-        sort_main_label.set_alignment(0,0.5)
-        sort_main_label.set_use_markup(True)
-        sort_main_vbox.pack_start(sort_main_label,False,False,4)
-        sort_table=gtk.Table(2,2,False)
-        sort_table.set_border_width(4)
-        self.sort_order_checkbutton=gtk.CheckButton(_("Ascending Order"))
-        sort_label=gtk.Label(_("Sorting Column"))
-        sort_label.set_alignment(0,0.5)
-        self.sort_combo=gtk.combo_box_entry_new_text()
-        self.sort_combo.child.set_editable(False)
-        self.sort_combo.set_size_request(130,-1)
-        sort_columns=[_("Subject"),_("From"),_("Date"),_("Score")]
-        for column in sort_columns:
-            self.sort_combo.append_text(column)
-
-        sort_table.attach(self.sort_order_checkbutton,0,1,0,1,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
-        sort_table.attach(self.sort_combo,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
-        sort_table.attach(sort_label,1,2,1,2,gtk.EXPAND|gtk.FILL,2)
-        sort_main_vbox.pack_start(sort_table,False,False)
+        label_groups_download=gtk.Label("<b>"+_("Download")+"</b>")
+        label_groups_download.set_use_markup(True)
+        label_groups_view=gtk.Label("<b>"+_("Visualization")+"</b>")
+        label_groups_view.set_use_markup(True)
+        label_groups_nav=gtk.Label("<b>"+_("Navigation")+"</b>")
+        label_groups_nav.set_use_markup(True)
         
-        groups_vbox.pack_start(sort_main_vbox,False,True)
-
+        groups_download_vbox=gtk.VBox()
+        groups_view_vbox=gtk.VBox()
+        groups_nav_vbox=gtk.VBox()
 
 
         purge_main_vbox=gtk.VBox()
@@ -1036,7 +1050,7 @@ class Config_Win:
         
         purge_main_vbox.pack_start(purge_table,False,False,4)
 
-        groups_vbox.pack_start(purge_main_vbox,False,True,2)
+        groups_download_vbox.pack_start(purge_main_vbox,False,True,2)
 
         articles_vbox=gtk.VBox()
         articles_vbox.set_border_width(4)
@@ -1057,7 +1071,59 @@ class Config_Win:
         articles_table.attach(limit_articles_label,1,2,2,3,gtk.EXPAND|gtk.FILL,gtk.FILL)
         
         articles_vbox.pack_start(articles_table,False,False)
-        groups_vbox.pack_start(articles_vbox,False,True,4)
+        groups_download_vbox.pack_start(articles_vbox,False,True,4)
+
+        auto_download_vbox=gtk.VBox()
+        auto_download_vbox.set_border_width(4)
+        auto_download_label=gtk.Label("<b>"+_("Automatic Header Download")+"</b>")
+        auto_download_label.set_alignment(0,0.5)
+        auto_download_label.set_use_markup(True)
+        auto_download_vbox.pack_start(auto_download_label,False,False,4)
+        auto_download_table=gtk.Table(1,1,False)
+        self.auto_download_checkbutton=gtk.CheckButton(_("Download Headers automatically"))
+        self.auto_download_spinbutton=gtk.SpinButton(gtk.Adjustment(value=30,lower=5,upper=100000,step_incr=1,page_incr=10))
+        timeout_label=gtk.Label(_("Minutes Between Downloads"))
+        self.auto_download_checkbutton.connect("clicked",self.change_auto_download_status)
+        
+        auto_download_table.attach(self.auto_download_checkbutton,0,1,0,1,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        auto_download_table.attach(self.auto_download_spinbutton,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        auto_download_table.attach(timeout_label,1,2,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL)
+
+        auto_download_vbox.pack_start(auto_download_table,False,False)
+        groups_download_vbox.pack_start(auto_download_vbox,False,False,4)
+
+
+
+
+
+        sort_main_vbox=gtk.VBox()
+        sort_main_vbox.set_border_width(4)
+        sort_main_label=gtk.Label("<b>"+_("Sorting Options")+"</b>")
+        sort_main_label.set_alignment(0,0.5)
+        sort_main_label.set_use_markup(True)
+        sort_main_vbox.pack_start(sort_main_label,False,False,4)
+        sort_table=gtk.Table(2,2,False)
+        sort_table.set_border_width(4)
+        self.sort_order_checkbutton=gtk.CheckButton(_("Ascending Order"))
+        sort_label=gtk.Label(_("Sorting Column"))
+        sort_label.set_alignment(0,0.5)
+        self.sort_combo=gtk.combo_box_entry_new_text()
+        self.sort_combo.child.set_editable(False)
+        self.sort_combo.set_size_request(130,-1)
+        sort_columns=[_("Subject"),_("From"),_("Date"),_("Score")]
+        for column in sort_columns:
+            self.sort_combo.append_text(column)
+
+        sort_table.attach(self.sort_order_checkbutton,0,1,0,1,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        sort_table.attach(self.sort_combo,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        sort_table.attach(sort_label,1,2,1,2,gtk.EXPAND|gtk.FILL,2)
+        sort_main_vbox.pack_start(sort_table,False,False)
+        
+        groups_view_vbox.pack_start(sort_main_vbox,False,True)
+
+
+
+
 
         charset_vbox=gtk.VBox()
         charset_vbox.set_border_width(4)
@@ -1093,9 +1159,57 @@ class Config_Win:
         charset_table.attach(charset_list_label,1,2,1,2,gtk.EXPAND|gtk.FILL,2) 
         
         charset_vbox.pack_start(charset_table,True,False,4)
+        groups_view_vbox.pack_start(charset_vbox,False,True,2)
+        
+        threading_vbox=gtk.VBox()
+        threading_vbox.set_border_width(4)
+        threading_label=gtk.Label("<b>"+_("Threading Method")+"</b>")
+        threading_label.set_alignment(0,0.5)
+        threading_label.set_use_markup(True)
+        threading_vbox.pack_start(threading_label,False,False,4)
+        threading_table=gtk.Table(1,1,False)
+        threading_table.set_border_width(4)
+        self.threading_method_radiobutton1=gtk.RadioButton(None,_("Fast (but imprecise) old Algorithm"))
+        self.threading_method_radiobutton2=gtk.RadioButton(self.threading_method_radiobutton1,_("Slow (but precise) new Algorithm"))
+        threading_table.attach(self.threading_method_radiobutton1,0,1,0,1,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        threading_table.attach(self.threading_method_radiobutton2,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        threading_vbox.pack_start(threading_table,True,False,4)
+        
+        groups_view_vbox.pack_start(threading_vbox,False,True,2)
+
+        main_nav_vbox=gtk.VBox()
+        main_nav_vbox.set_border_width(4)
+        misc_main_label=gtk.Label("<b>"+_("Miscellaneous")+"</b>")
+        misc_main_label.set_alignment(0,0.5)
+        misc_main_label.set_use_markup(True)
+        main_nav_vbox.pack_start(misc_main_label,False,False,4)
+        misc_table=gtk.Table(5,2,False)
+        misc_table.set_border_width(4)
+        self.advance_on_mark_checkbutton=gtk.CheckButton(_("Advance to the Next Article on Mark"))
+        self.oneclick_checkbutton=gtk.CheckButton(_("One Click Enter Group"))
+        self.oneclick_article_checkbutton=gtk.CheckButton(_("One Click Enter Article"))
+        self.expand_groups_checkbutton=gtk.CheckButton(_("Expand Group on Entering"))
+        one_key_label=gtk.Label(_("Scroll Text (% of page)"))
+        one_key_label.set_size_request(200,-1)
+        one_key_label.set_alignment(0,0.5)
+        self.one_key_spin=gtk.SpinButton(gtk.Adjustment(value=50,lower=1,upper=100,step_incr=1,page_incr=10))
+        
+        misc_table.attach(self.advance_on_mark_checkbutton,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        misc_table.attach(self.oneclick_checkbutton,0,1,2,3,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        misc_table.attach(self.oneclick_article_checkbutton,0,1,3,4,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        misc_table.attach(self.expand_groups_checkbutton,0,1,4,5,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
+        misc_table.attach(self.one_key_spin,0,1,5,6,gtk.FILL,gtk.FILL,16,2)
+        misc_table.attach(one_key_label,1,2,5,6,gtk.EXPAND|gtk.FILL,gtk.FILL,2)
+
+        main_nav_vbox.pack_start(misc_table,False,False)
+
+        groups_nav_vbox.pack_start(main_nav_vbox,False,True,2)
+
+        
+        notebook.append_page(groups_download_vbox,label_groups_download)
+        notebook.append_page(groups_view_vbox,label_groups_view)
+        notebook.append_page(groups_nav_vbox,label_groups_nav)
 
-        groups_vbox.pack_start(charset_vbox,False,True,2)
-        notebook.append_page(groups_vbox,label_groups)
         return notebook
 
 
@@ -1147,7 +1261,7 @@ class Config_Win:
         self.editor_checkbutton=gtk.CheckButton(_("Always Use External Editor"))
         self.editor_entry=gtk.Entry()
         editor_tooltip=gtk.Tooltips()
-        editor_tooltip.set_tip(self.editor_entry,_("Type the editor launcher, %s represents the filename.\nExamples:\n\nxterm -e vim %s\ngvim -f %s\nnotepad.exe %s\n\nNOTE: This feature works only with *Nix and Windows systems"))
+        editor_tooltip.set_tip(self.editor_entry,_("""Type the editor launcher, %s represents the filename.\nExamples:\n\nxterm -e vim %s\ngvim -f %s\nnotepad.exe %s\n"C:\Program Files\Notepad++\Notepad++.exe" %s -nosession\n\nNOTE: This feature works only with *Nix and Windows systems"""))
 
         editor_label=gtk.Label(_("External Editor Command"))
         editor_label.set_alignment(0,0.5)
@@ -1215,34 +1329,9 @@ class Config_Win:
         lang_vbox.pack_start(lang_hbox,False,False)
 
 
-        misc_main_vbox=gtk.VBox()
-        misc_main_vbox.set_border_width(4)
-        misc_main_label=gtk.Label("<b>"+_("Miscellaneous")+"</b>")
-        misc_main_label.set_alignment(0,0.5)
-        misc_main_label.set_use_markup(True)
-        misc_main_vbox.pack_start(misc_main_label,False,False,4)
-        misc_table=gtk.Table(5,2,False)
-        misc_table.set_border_width(4)
-        self.advance_on_mark_checkbutton=gtk.CheckButton(_("Advance to the Next Article on Mark"))
-        self.oneclick_checkbutton=gtk.CheckButton(_("One Click Enter Group"))
-        self.oneclick_article_checkbutton=gtk.CheckButton(_("One Click Enter Article"))
-        one_key_label=gtk.Label(_("Scroll Text (% of page)"))
-        one_key_label.set_size_request(200,-1)
-        one_key_label.set_alignment(0,0.5)
-        self.one_key_spin=gtk.SpinButton(gtk.Adjustment(value=50,lower=1,upper=100,step_incr=1,page_incr=10))
-        
-        misc_table.attach(self.advance_on_mark_checkbutton,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
-        misc_table.attach(self.oneclick_checkbutton,0,1,2,3,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
-        misc_table.attach(self.oneclick_article_checkbutton,0,1,3,4,gtk.EXPAND|gtk.FILL,gtk.FILL,16,2)
-        misc_table.attach(self.one_key_spin,0,1,4,5,gtk.FILL,gtk.FILL,16,2)
-        misc_table.attach(one_key_label,1,2,4,5,gtk.EXPAND|gtk.FILL,gtk.FILL,2)
-
-        misc_main_vbox.pack_start(misc_table,False,False)
-
         miscellaneous_vbox.pack_start(browser_main_vbox,False,True,2)
         miscellaneous_vbox.pack_start(editor_main_vbox,False,True,2)
         miscellaneous_vbox_2.pack_start(lang_vbox,False,True,2)
-        miscellaneous_vbox_2.pack_start(misc_main_vbox,False,True,2)
         
         notebook.append_page(miscellaneous_vbox,label_misc)
         notebook.append_page(miscellaneous_vbox_2,label_misc_2)
