@@ -33,7 +33,7 @@ def my_xover(self,start,end):
                                 elem[7],
                                 elem[8]))
         except IndexError:
-            raise NNTPDataError(line)
+            raise nntplib.NNTPDataError(line)
     return resp,xover_lines
 
 
