@@ -715,7 +715,7 @@ class Edit_Mail_Win:
         self.mode=mode
         self.outboxManager=outboxManager
         self.isSent=isSent
-        self.id_name=id_name
+        self.id_name=id_name.encode("utf-8")
 
 
 
