@@ -798,7 +798,9 @@ class Edit_Win:
             is_fup=False
         else:
             is_fup=True
-        self.id_name=id_name
+        print type(id_name),repr(id_name)
+        self.id_name=id_name.encode("utf-8")
+        print type(self.id_name),repr(self.id_name)
         self.outboxManager=outboxManager
         self.pathToArticle=pathToArticle
         self.isSent=isSent
