@@ -2,10 +2,11 @@ import gtk
 import re
 from xpn_src.Article import Article
 import cPickle
-import shelve
+
 import os
 import glob
 from xpn_src.UserDir import get_wdir
+from xpn_src.Articles_DB import Articles_DB
 
 
 class Find_Win:
@@ -466,38 +467,30 @@ class GlobalSearch:
         model,iter=treesel.get_selected()
         column=self.main_win.threads_pane.threads_tree.get_column(0)
 
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            self.main_win.statusbar.push(1,_("No Subscribed Groups"))
-            list=[]
-        else:
-            list=cPickle.load(f)
-            name="global.search.results."+str(len(glob.glob(os.path.join(self.wdir,"groups_info","global.search.results*")))+1)
-            if not os.path.isdir(os.path.join(self.wdir,"groups_info",name)):
-                os.makedirs(os.path.join(self.wdir,"groups_info",name))
-            results=shelve.open(os.path.join(self.wdir,"groups_info",name,name))
-            unread_number=0
-            for group in list:
-                articles=shelve.open(os.path.join(self.wdir,"groups_info/",group[0],group[0]))
-                for article in articles.itervalues():
-                    found=self.is_match(non_empty,article,rule,match_rule,from_string,subj_string,msgid_string,ref_string,body_string)
-                    if found:
-                        results[article.msgid]=article
-                        if not article.is_read:
-                            unread_number=unread_number+1
-                articles.close()
-            total=len(results.keys())
-            results.close()
-            #self.main_win.groups_pane.show_list([("global.search.results",str(unread_number)+" ("+str(total)+")"),],True)
-            self.main_win.groups_pane.model.append((name,str(unread_number)+" ("+str(total)+")",False))
-            self.main_win.threads_pane.clear()
-            self.main_win.article_pane.clear()
+        subscribed=self.art_db.getSubscribed()
+        name="global.search.results."+str(len(glob.glob(os.path.join(self.wdir,"groups_info","global.search.results*")))+1)
+        if not os.path.isdir(os.path.join(self.wdir,"groups_info",name)):
+            os.makedirs(os.path.join(self.wdir,"groups_info",name))
+        self.art_db.createGroup(name)
+        unread_number=0
+        for group in subscribed:
+            for article in self.art_db.getArticles(group[0]):
+                found=self.is_match(non_empty,article,rule,match_rule,from_string,subj_string,msgid_string,ref_string,body_string)
+                if found:
+                    self.art_db.insertArticle(name,article)
+                    if not article.is_read:
+                        unread_number=unread_number+1
+        total,unread_number=self.art_db.getArticlesNumbers(name)
+        #self.main_win.groups_pane.show_list([("global.search.results",str(unread_number)+" ("+str(total)+")"),],True)
+        self.main_win.groups_pane.model.append((name,str(unread_number)+" ("+str(total)+")",False))
+        self.main_win.threads_pane.clear()
+        self.main_win.article_pane.clear()
 
 
 
     def __init__(self,main_win):
         self.wdir=get_wdir()
+        self.art_db=main_win.art_db
         self.main_win=main_win
         self.window=gtk.Window(gtk.WINDOW_TOPLEVEL)
         self.window.connect("delete_event",self.delete_event)
@@ -506,7 +499,7 @@ class GlobalSearch:
         self.window.set_position(gtk.WIN_POS_CENTER)
         self.window.set_default_size(350,300)
         self.window.set_icon(gtk.gdk.pixbuf_new_from_file("pixmaps/global_search.xpm"))
-
+        
 
         vbox=gtk.VBox()
         vbox.set_border_width(8)
