@@ -1,9 +1,7 @@
 import sys
-import shelve
 import gtk
 import gobject
 import socket
-import cPickle
 import time
 import re
 import threading, Queue
@@ -16,10 +14,10 @@ from xpn_src.Groups_Pane import Groups_Pane,Groups_List
 from xpn_src.ListThread import ListThread
 from xpn_src.Article import Article
 from xpn_src.Config_File import Config_File
-from xpn_src.Score import Score_Rules
 from xpn_src.Connections_Handler import Connection, SSLConnection
 from xpn_src.UserDir import get_wdir
 from xpn_src.Dialogs import Dialog_OK
+from xpn_src.Articles_DB import Articles_DB,Groups_DB
 
 
 try:
@@ -54,13 +52,11 @@ class Groups_Win:
     def ended_listing(self, data):
         lock = threading.Lock()
         lock.acquire()
-        list = self.listThread.queue.get()
+        groups_list = self.listThread.queue.get()
         lock.release()
-        list.sort()
+        groups_list.sort()
         server_name=self.server_combo.get_active_text()        
-        flist = file(os.path.join(self.wdir,"groups_info",server_name+".groups.dat"),'wb')
-        cPickle.dump(list,flist,1)
-        flist.close()
+        self.groups_list_db.createList(groups_list,server_name)
         self.update_total_list()
         return 1
 
@@ -68,19 +64,11 @@ class Groups_Win:
         file_list=os.listdir(os.path.join(self.wdir,"groups_info"))
         total_list=[]
         for file_name in file_list:
-            if file_name.endswith(".groups.dat"):
-                f=file(os.path.join(self.wdir,"groups_info",file_name),"rb")
-                try:
-                    list=cPickle.load(f)
-                except EOFError:
-                    self.statusbar.push(1,_("Corrupted file:")+file_name)
-                else:
-                    total_list += list
-                f.close()
+            if file_name.endswith(".groups.sqlitedb"):
+                groups_list=self.groups_list_db.getList(file_name)
+                total_list += groups_list
         self.total_list=total_list
-        flist = file(os.path.join(self.wdir,"groups_info/groups.dat"),'wb')
-        cPickle.dump(self.total_list,flist,1)
-        flist.close()
+        self.groups_list_db.createList(total_list,"","groups.sqlitedb")
         self.server_list.show_list(self.total_list)
         
 
@@ -128,24 +116,12 @@ class Groups_Win:
 
 
     def show_subscribed(self):
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            #self.statusbar.push(1,_("No Subscribed Groups"))
-            pass
-        else:
-            list=cPickle.load(f)
-            new_list=[]
-            for group in list:
-                try:
-                    articles=shelve.open(os.path.join(self.wdir,"groups_info/",group[0],group[0]))
-                except:
-                    self.statusbar.push(1,_("Missing %s file") % (group[0],))
-                else:                    
-                    new_list.append((group[0],str(len(articles.keys()))))
-                    articles.close()
-            self.subscribed_list.show_list(new_list)
-            f.close()
+        list=self.art_db.getSubscribed()
+        new_list=[]
+        for group in list:
+            total,unread_number=self.art_db.getArticlesNumbers(group[0])
+            new_list.append((group[0],total))
+        self.subscribed_list.show_list(new_list)
 
 
     def search_group(self,obj):
@@ -178,25 +154,10 @@ class Groups_Win:
     def show_full_list(self,obj):
         self.server_list.show_list(self.total_list)
 
-    def retrieve_body(self,article_to_read,group,server_name):
-        body=article_to_read.get_body()
-        if not body:
-            message,headerList,body,bodyRetrieved=self.connectionsPool[server_name].getBody(article_to_read.number,article_to_read.msgid,group)
-            if headerList:
-                article_to_read.parse_header_list(headerList)
-            if bodyRetrieved:
-                article_to_read.set_body(body,'\n'.join(headerList+['']+body))
-                body=article_to_read.get_body()
-                article_to_read.marked_for_download=False
-        return body
+
         
     def download_headers(self,group,articles_number,server_name):
         last_number=str(0)
-        watched=self.get_watched()
-        ignored=self.get_ignored()
-        articles=shelve.open(os.path.join(self.wdir,"groups_info/",group,group))
-        articles.clear()
-        score_rules=Score_Rules()
         #Downloading headers
         self.progressbar.set_text(_("Fetching Headers"))
         self.progressbar.set_fraction(1/float(2))
@@ -213,39 +174,11 @@ class Groups_Win:
         self.progressbar.set_fraction(2/float(2))
         while gtk.events_pending():
             gtk.main_iteration(False)
+        
+        self.art_db.createGroup(group)
+        self.art_db.addHeaders(group,total_headers,server_name,self.connectionsPool)
             
-        for headers in total_headers:
-            number,subject,from_name,date,msgid,references,bytes,lines,xref=headers
-            xpn_article=Article(number,msgid,from_name,references,subject,date,self.configs["fallback_charset"],group,xref,bytes,lines)
-            try:
-                index=references.rindex("<")
-            except ValueError:
-                last_ref=""
-            else:
-                last_ref=references[index:]
-            #applying score rules
-            score=score_rules.apply_score_rules(xpn_article,group)
-            xpn_article.set_score(score)
-            #applying score actions
-            xpn_article,actions,watched,ignored=score_rules.apply_action_rules(xpn_article,group,watched,ignored)
-            if not "kill" in actions:
-                if ((self.configs["download_bodies"]=="True" and not "markread" in actions) or ("retrieve" in actions) or (last_ref in watched)) and not (last_ref in ignored):
-                    body=self.retrieve_body(xpn_article,group,server_name)
-                if last_ref in ignored:
-                    xpn_article.is_read=True
-                    xpn_article.ignore=True
-                    ignored.add(xpn_article.msgid)
-                    watched.discard(xpn_article.msgid)
-                    xpn_article.watch=False
-                if last_ref in watched:
-                    xpn_article.watch=True
-                    watched.add(xpn_article.msgid)
-                    ignored.discard(xpn_article.msgid)
-                    xpn_article.ignore=False
-                articles[xpn_article.msgid]=xpn_article
-        articles.close()
-        self.dump_watched(watched)
-        self.dump_ignored(ignored)
+        
         self.statusbar.push(1,_("Group subscribed"))
         self.progressbar.set_fraction(0)
         self.progressbar.set_text("")
@@ -271,8 +204,7 @@ class Groups_Win:
 
     def subscribe_group(self,group_to_subscribe,server_name):
         articles_number=self.articles_spinbutton.get_value_as_int()
-        if not os.path.isdir(os.path.join(self.wdir,"groups_info",group_to_subscribe)):
-            os.makedirs(os.path.join(self.wdir,"groups_info",group_to_subscribe))
+
 
         cp=ConfigParser.ConfigParser()
         cp.read(os.path.join(get_wdir(),"dats","id.txt"))
@@ -283,37 +215,17 @@ class Groups_Win:
             Dialog_OK(_("First you have to create at least one Identity"))
         else:    
             last,message=self.download_headers(group_to_subscribe,articles_number,server_name)
-            subscribed_groups=[]
-            try:
-                f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-            except IOError:
-                subscribed_groups.append([group_to_subscribe,last,server_name,id_name])
-            else:
-                subscribed_groups=cPickle.load(f)
-                f.close()
-                if subscribed_groups:
-                    already_in=False
-                    for group in subscribed_groups:
-                        if group[0]==group_to_subscribe:
-                            already_in=True
-                            to_remove=group
-                    if already_in:
-                        subscribed_groups.remove(to_remove) 
-                subscribed_groups.append([group_to_subscribe,last,server_name,id_name])
-        
-            #refresh the subscribed file
-            try:
-                f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"wb")
-            except IOError:
-                self.statusbar.push(1,_("Problems while opening subscribed.dat"))
-            else:
-                subscribed_groups.sort()
-                cPickle.dump(subscribed_groups,f,1)
-                f.close() 
+
+            self.art_db.removeSubscribed(group_to_subscribe)
+            self.art_db.addSubscribed(group_to_subscribe,last,server_name,id_name)
 
             if message.lower().startswith("server error"):
                 self.unsubscribe_group(group_to_subscribe)
                 self.statusbar.push(1,_("The Group Name seems to be wrong"))
+            if message.lower().startswith("no connection with"):
+                self.unsubscribe_group(group_to_subscribe)
+                self.statusbar.push(1,message)
+                
 
 
     def unsubscribe_selected_groups(self,obj):
@@ -327,60 +239,14 @@ class Groups_Win:
 
 
     def unsubscribe_group(self,group_to_unsubscribe):
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            self.statusbar.push(1,_("Missing subscribed.dat"))
-        else:
-            subscribed=cPickle.load(f)
-            f.close()
-            i=0
-            success=0
-            while (i<len(subscribed)) and (success==0):
-                if group_to_unsubscribe==subscribed[i][0]:
-                    success=1
-                    subscribed.remove(subscribed[i])
-                    shutil.rmtree(os.path.join(self.wdir,"groups_info/",group_to_unsubscribe))
-                    self.statusbar.push(1,_("Group removed"))
-                i=i+1
-            try:
-                f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"wb")
-            except IOError:
-                self.statusbar.push(1,_("Problems while opening subscribed.dat"))
-            else:
-                cPickle.dump(subscribed,f,1)
-                f.close()
+        removed=self.art_db.removeSubscribed(group_to_unsubscribe)
+        if removed:
+            self.art_db.closeGroups((group_to_unsubscribe,))
+            shutil.rmtree(os.path.join(self.wdir,"groups_info/",group_to_unsubscribe))
+            self.statusbar.push(1,_("Group removed"))
 
 
-    def get_watched(self):
-        try:
-            f=open(os.path.join(self.wdir,"dats/watch.dat"),"rb")
-        except IOError:
-            watched=set()
-        else:
-            watched=cPickle.load(f)
-            f.close()
-        return watched
 
-    def dump_watched(self,watched):
-        f=open(os.path.join(self.wdir,"dats/watch.dat"),"wb")
-        cPickle.dump(watched,f,1)
-        f.close()
-
-    def get_ignored(self):
-        try:
-            f=open(os.path.join(self.wdir,"dats/ignore.dat"),"rb")
-        except IOError:
-            ignored=set()
-        else:
-            ignored=cPickle.load(f)
-            f.close()
-        return ignored
-
-    def dump_ignored(self,ignored):
-        f=open(os.path.join(self.wdir,"dats/ignore.dat"),"wb")
-        cPickle.dump(ignored,f,1)
-        f.close()
 
     def change_live_search_status(self,obj):
         live_search=self.live_search_checkbutton.get_active()
@@ -417,12 +283,14 @@ class Groups_Win:
         cp=ConfigParser.ConfigParser()
         cp.read(os.path.join(get_wdir(),"dats","servers.txt"))
         self.connectionsPool=dict()
+        
         for server in cp.sections():
             if cp.get(server,"nntp_use_ssl")=="True":
                 self.connectionsPool[server]=SSLConnection(cp.get(server,"server"),cp.get(server,"port"),cp.get(server,"auth"),cp.get(server,"username"),cp.get(server,"password"))
             else:
                 self.connectionsPool[server]=Connection(cp.get(server,"server"),cp.get(server,"port"),cp.get(server,"auth"),cp.get(server,"username"),cp.get(server,"password"))
-
+        self.art_db=main_win.art_db
+        self.groups_list_db=Groups_DB()
         self.main_win=main_win
         self.win=gtk.Window(gtk.WINDOW_TOPLEVEL)
         self.win.set_modal(True)
@@ -616,16 +484,12 @@ class Groups_Win:
         while gtk.events_pending():
             gtk.main_iteration(False)
         try:
-            f=open(os.path.join(self.wdir,"groups_info/groups.dat"),"rb")
+            f=open(os.path.join(self.wdir,"groups_info/groups.sqlitedb"),"rb")
         except IOError:
             self.statusbar.push(1,_("You have to download newsgroups list"))
         else:
-            try:
-                list=cPickle.load(f)
-            except EOFError:
-                self.statusbar.push(1,_("You have to download newsgroups list"))
-            else:
-                self.total_list=list
-                self.server_list.show_list(list)
-                self.statusbar.push(1,_("Newsgroups list loaded"))
-            f.close()
+            groups_list=self.groups_list_db.getList("groups.sqlitedb")
+            self.total_list=groups_list
+            self.server_list.show_list(groups_list)
+            self.statusbar.push(1,_("Newsgroups list loaded"))
+            
