@@ -17,105 +17,117 @@ def escape(data):
 
 def load_actions():
     main_actions=[
-        ("File",_("_File")),
-        ("groups",_("_Groups List..."),"<Control>G"),
-        ("rules",_("_Scoring and Action Rules..."),"<Alt>S"),
-        ("logs",_("Server _Logs..."),"<Alt>L"),
-        ("exp_newsrc",_("Export _Newsrc..."),None),
-        ("imp_newsrc",_("_Import Newsrc..."),None),
-        ("accelerator",_("_Modify Keyboard Shortcuts..."),None),
-        ("conf",_("_Preferences..."),"<Alt>P"),
-        ("exit",_("_Exit"),"<Control>E"),
-        ("Subscribed",_("Subscribed _Groups")),
-        ("gethdrs",_("_Get New Headers in Subscribed Groups"),"<Control>H"),
-        ("gethdrssel",_("_Get New Headers in Selected Groups"),"<Control><Shift>H"),
-        ("getbodies",_("Get Marked Article _Bodies in Subscribed Groups"),"<Control>B"),
-        ("getbodiessel",_("Get Marked Article _Bodies in Selected Groups"),"<Control><Shift>B"),
-        ("expand",_("_Expand All Threads"),None),
-        ("collapse",_("_Collapse All Threads"),None),
-        ("expand_row",_("_Expand Selected SubThread"),None),
-        ("collapse_row",_("_Collapse Selected SubThread"),None),
-        ("group",_("_View Next Group"),"G"),
-        ("mark_group",_("Mark Group ...")),
-        ("mark",_("_Mark Selected Groups as Read"),None),
-        ("mark_unread_group",_("Mark Selected Groups as Unread"),None),
-        ("mark_download_group",_("Mark Group for Retrieving"),"<Control><Shift>M"),
-        ("keepall",_("Keep Articles in Selected Groups"),None),
-        ("markall",_("Mark _All Groups as Read"),None),
-        ("markall_unread",_("Mark All Groups as Unread"),None),
-        ("view_group_opts",_("View Options")),
-        ("show_threads",_("_Show Threads"),"<Shift><Alt>T"),
-        ("show_all_read_threads",_("_Show All Read Threads"),None),
-        ("show_read_articles",_("_Show Read Articles"),"<Shift><Alt>R"),
-        ("show_unread_articles",_("_Show UnRead Articles"),"<Control><Shift>R"),
-        ("show_kept_articles",_("_Show Kept Articles"),"<Shift><Alt>k"),
-        ("show_unkept_articles",_("_Show UnKept Articles"),"<Control><Shift>k"),
-        ("show_watched_articles",_("_Show Watched Articles"),"<Shift><Alt>W"),
-        ("show_ignored_articles",_("_Show Ignored Articles"),"<Shift><Alt>I"),
-        ("show_unwatchedignored_articles",_("_Show UnWatched/UnIgnored Articles"),"<Control><Shift>W"),
-        ("show_score_neg_articles",_("_Show Articles with Score<0"),"<Shift><Alt>S"),
-        ("show_score_zero_articles",_("_Show Articles with Score=0"),"<Control><Alt>S"),
-        ("show_score_pos_articles",_("_Show Articles with Score>0"),"<Control><Shift>S"),
-        ("raw",_("_View Raw Article"),"H"),
+        ("File",_("File")),
+        ("groups",_("Groups List..."),None),
+        ("rules",_("Scoring and Action Rules..."),None),
+        ("logs",_("Server Logs..."),None),
+        ("exp_newsrc",_("Export Newsrc..."),None),
+        ("imp_newsrc",_("Import Newsrc..."),None),
+        ("accelerator",_("Modify Keyboard Shortcuts..."),None),
+        ("conf",_("Preferences..."),None),
+        ("exit",_("Exit"),"<Control>E"),
+        ("Search",_("Search")),
+        ("find",_("Find Article..."),"<Control>F"),
+        ("filter",_("Filter Articles..."),"KP_Divide"),
+        ("global",_("Global Search ..."),"<Control><Shift>G"),
+        ("search",_("Search in the Body..."),"<Control>S"),
+        ("View",_("View")),
+        ("view_articles_opts",_("Articles View Options")),
+        ("raw",_("View Raw Article"),"H"),
         ("spoiler",_("Show Spoilered Text"),"<Control>L"),
-        ("show_quote",_("Show Quoted Text"),"<Control>Q"),
-        ("show_sign",_("Show Signatures"),"<Control>S"),
-        ("fixed",_("Fixed Pitch Font"),"<Control>F"),
-        ("find",_("_Find Article..."),"<Shift>F"),
-        ("global",_("Global _Search ..."),"<Control><Shift>G"),
-        ("apply_score",_("Apply Scoring and Action Rules"),None),
-        ("groups_vs_id",_("Assign Identities to Groups"),None),        
-        ("Articles",_("_Articles")),
+        ("show_quote",_("Show Quoted Text"),"<Shift>Q"),
+        ("show_sign",_("Show Signatures"),"<Shift>S"),
+        ("fixed",_("Fixed Pitch Font"),"<Shift>F"),      
+        ("show_hide_headers",_("Show/Hide Headers"),"<Shift>H"),
+        ("rot13",_("ROT13 Selected Text"),"<Control>R"),
+        ("view_group_opts",_("Groups View Options")),
+        ("show_threads",_("Show Threads"),None),
+        ("show_all_read_threads",_("Show All Read Threads"),None),
+        ("show_threads_without_watched",_("Show Threads Without Watched Articles"),None),
+        ("show_read_articles",_("Show Read Articles"),None),
+        ("show_unread_articles",_("Show UnRead Articles"),None),
+        ("show_kept_articles",_("Show Kept Articles"),None),
+        ("show_unkept_articles",_("Show UnKept Articles"),None),
+        ("show_watched_articles",_("Show Watched Articles"),None),
+        ("show_ignored_articles",_("Show Ignored Articles"),None),
+        ("show_unwatchedignored_articles",_("Show UnWatched/UnIgnored Articles"),None),
+        ("show_score_neg_articles",_("Show Articles with Score<0"),None),
+        ("show_score_zero_articles",_("Show Articles with Score=0"),None),
+        ("show_score_pos_articles",_("Show Articles with Score>0"),None),
+        ("Navigate",_("Navigate")),
+        ("group",_("View Next Group"),"G"),
         ("previous",_("Read Previous Article"),"B"),
-        ("next",_("Read Next Article"),"<Alt>N"),
-        ("next_unread",_("Read _Next Unread Article"),"N"),
+        ("next",_("Read Next Article"),"<Shift>N"),
+        ("next_unread",_("Read Next Unread Article"),"N"),
         ("parent",_("Read Parent Article"),"U"),
         ("one_key",_("One-Key Reading"),"space"),
         ("move_up",_("One-Key Scroll Up"),"<Control>space"),
-        ("search",_("_Search in the Body..."),"<Shift>S"),
-        ("view_articles_opts",_("View Options")),
-        ("show_hide_headers",_("Show/Hide _Headers"),"<Alt>H"),
-        ("rot13",_("_ROT13 Selected Text"),"<Control>R"),
+        ("focus_article",_("Focus to Article Pane"),"3"),
+        ("focus_groups",_("Focus to groups Pane"),"1"),
+        ("focus_threads",_("Focus to Threads Pane"),"2"),
+        ("zoom_article",_("Zoom Article Pane"),"<Control>3"),
+        ("zoom_groups",_("Zoom groups Pane"),"<Control>1"),
+        ("zoom_threads",_("Zoom Threads Pane"),"<Control>2"),
+        ("Subscribed",_("Subscribed Groups")),
+        ("gethdrs",_("Get New Headers in Subscribed Groups"),"<Control>H"),
+        ("gethdrssel",_("Get New Headers in Selected Groups"),"<Control><Shift>H"),
+        ("getbodies",_("Get Marked Article Bodies in Subscribed Groups"),"<Control>B"),
+        ("getbodiessel",_("Get Marked Article Bodies in Selected Groups"),"<Control><Shift>B"),
+        ("expand",_("Expand All Threads"),None),
+        ("collapse",_("Collapse All Threads"),None),
+        ("expand_row",_("Expand Selected SubThread"),None),
+        ("collapse_row",_("Collapse Selected SubThread"),None),
+        ("mark_group",_("Mark Group ...")),
+        ("mark",_("Mark Selected Groups as Read"),None),
+        ("mark_unread_group",_("Mark Selected Groups as Unread"),None),
+        ("mark_download_group",_("Mark Group for Retrieving"),None),
+        ("keepall",_("Keep Articles in Selected Groups"),None),
+        ("markall",_("Mark All Groups as Read"),None),
+        ("markall_unread",_("Mark All Groups as Unread"),None),
+        ("apply_score",_("Apply Scoring and Action Rules"),None),
+        ("groups_vs_id",_("Assign Identities to Groups"),None),
+        ("Articles",_("Articles")),
+        ("post",_("Post New Article..."),"P"),
+        ("followup",_("Follow-Up To Newsgroup..."),"F"),
+        ("reply",_("Reply By Mail..."),"<Shift>M"),
+        ("outbox_manager",_("Open Outbox Manager"),None),
+        ("cancel",_("Cancel Article..."),None),
+        ("supersede",_("Supersede Article..."),None),
         ("flags",_("Flags & Score")),
         ("mark_read",_("Mark Article as Read"),"<Shift>R"),
         ("mark_unread",_("Mark Article as UnRead"),"<Shift>U"),
         ("mark_download",_("Mark Article for Retrieving"),"M"),
         ("keep",_("Keep Article"),"<Shift>K"),
+        ("delete",_("Delete Article"),"<Control><Shift>D"),
         ("mark_unread_sub",_("Mark SubThread as UnRead"),None),
         ("mark_read_sub",_("Mark SubThread as Read"),None),
-        ("mark_download_sub",_("Mark SubThread for Retrieving"),"<Control>M"),
+        ("mark_download_sub",_("Mark SubThread for Retrieving"),None),
         ("keep_sub",_("Keep SubThread"),None),
         ("watch",_("Watch SubThread"),"<Shift>W"),
         ("ignore",_("Ignore SubThread"),"<Shift>I"),
         ("raise_score",_("Raise Author Score"),None),
         ("lower_score",_("Lower Author Score"),None),
         ("set_score",_("Set Author Score"),None),
-        ("post",_("_Post New Article..."),"P"),
-        ("outbox_manager",_("_Open Outbox Manager"),"<Shift>O"),
-        ("followup",_("_Follow-Up To Newsgroup..."),"F"),
-        ("reply",_("Reply By _Mail..."),"<Shift>M"),
-        ("supersede",_("Supersede Article..."),None),
-        ("cancel",_("Cancel Article..."),None),
         ("Help",_("Help")),
-        ("about",_("_About..."),None)]
+        ("about",_("About..."),None)]
 
     edit_actions=[
-        ("Article",_("_Article")),
-        ("send",_("_Send Article"),"<Control>S"),
-        ("send_later",_("Send Article _Later"),"<Control><Shift>S"),
+        ("Article",_("Article")),
+        ("send",_("Send Article"),"<Control>S"),
+        ("send_later",_("Send Article Later"),"<Control><Shift>S"),
         ("save_draft",_("Save Article as Draft"),"<Alt>D"),
-        ("discard",_("_Discard Article"),"<Control>D"),
-        ("rot13",_("_ROT13 Selected Text"),"<Control>R"),
-        ("editor",_("Launch External _Editor"),"<Alt>E"),
-        ("spoiler",_("_Insert Spoiler Char"),"<Control>L")]
+        ("discard",_("Discard Article"),"<Control>D"),
+        ("rot13",_("ROT13 Selected Text"),"<Control>R"),
+        ("editor",_("Launch External Editor"),"<Alt>E"),
+        ("spoiler",_("Insert Spoiler Char"),"<Control>L")]
 
     outbox_actions=[
-        ("Outbox",_("_Outbox")),
-        ("send_article",_("_Send Queued Articles"),"<Control>S"),
-        ("send_mail",_("Send Queued _Mails"),"<Control><Shift>S"),
-        ("edit",_("_Edit Article/Mail"),"E"),
-        ("delete",_("_Delete Article/Mail"),"Delete"),
-        ("exit",_("_Exit"),"<Control>E")]
+        ("Outbox",_("Outbox")),
+        ("send_article",_("Send Queued Articles"),"<Control>S"),
+        ("send_mail",_("Send Queued Mails"),"<Control><Shift>S"),
+        ("edit",_("Edit Article/Mail"),"E"),
+        ("delete",_("Delete Article/Mail"),"Delete"),
+        ("exit",_("Exit"),"<Control>E")]
 
     return main_actions,edit_actions,outbox_actions
 
@@ -353,24 +365,59 @@ class KeyBindings:
         
 
     def load_list(self):
-        iter_root_mainwin=self.model.append(None,["main",_("Main Window"),"",False])
+        self.model.clear()
         main_actions,edit_actions,outbox_actions=load_actions()
         main_shortcuts=load_shortcuts("main")
         edit_shortcuts=load_shortcuts("edit")
         outbox_shortcuts=load_shortcuts("outbox")
+        #0:Short Name 1:Long Name 2:Accelerator 3:Dump
 
+        iter_root_mainwin=self.model.append(None,["main",_("Main Window"),"",False])
         for action in main_actions:
-            if len(action)>2:
-                self.model.append(iter_root_mainwin,[action[0],action[1],main_shortcuts[action[0]],True])
+            if len(action) == 2:
+                iter_root_menu=self.model.append(iter_root_mainwin,[action[0],action[1],"",False])
+            else:
+                self.model.append(iter_root_menu,[action[0],action[1],main_shortcuts[action[0]],True])
+
         iter_root_editwin=self.model.append(None,["edit",_("Edit Window"),"",False])
         for action in edit_actions:
-            if len(action)>2:
-                self.model.append(iter_root_editwin,[action[0],action[1],edit_shortcuts[action[0]],True])
+            if len(action) == 2:
+                iter_root_menu=self.model.append(iter_root_editwin,[action[0],action[1],"",False])
+            else:                
+                self.model.append(iter_root_menu,[action[0],action[1],edit_shortcuts[action[0]],True])
+
         iter_root_outboxwin=self.model.append(None,["outbox",_("Outbox Window"),"",False])
         for action in outbox_actions:
-            if len(action)>2:
-                self.model.append(iter_root_outboxwin,[action[0],action[1],outbox_shortcuts[action[0]],True])
+            if len(action) == 2:
+                iter_root_menu=self.model.append(iter_root_outboxwin,[action[0],action[1],"",False])
+            else:                
+                self.model.append(iter_root_menu,[action[0],action[1],outbox_shortcuts[action[0]],True])
+    
+    def reset_defaults(self,obj):
+        try: os.remove(os.path.join(get_wdir(),"dats/shortcuts.dat"))
+        except: pass
+        self.load_list()
         
+    def clear_shortcuts(self,obj):
+        iter_current=self.model.get_iter_first()
+        while iter_current:
+            to_dump=self.model.get_value(iter_current,3)
+            if to_dump:
+                self.model.set_value(iter_current,2,"")
+
+            #let's cycle the tree
+            if self.model.iter_has_child(iter_current):
+                iter_current=self.model.iter_children(iter_current)
+            else:
+                iter_next=self.model.iter_next(iter_current)
+                while not iter_next:
+                    prev_iter=self.model.iter_parent(iter_current)
+                    iter_current=prev_iter
+                    if not prev_iter:
+                        break
+                    iter_next=self.model.iter_next(iter_current)
+                iter_current=iter_next
+                
     def __init__(self,main_win):
         self.main_win=main_win
         self.window=gtk.Window(gtk.WINDOW_TOPLEVEL)
@@ -401,17 +448,29 @@ class KeyBindings:
         self.button_change=gtk.Button(_("Change Shortcut"))
         self.button_change.connect("clicked",self.change_shortcut)
 
+        self.button_default=gtk.Button(_("Default Shortcuts"))
+        self.button_default.connect("clicked",self.reset_defaults)
+        
+        self.button_clear_shortcuts=gtk.Button(_("Clear Shortcuts"))
+        self.button_clear_shortcuts.connect("clicked",self.clear_shortcuts)
+        
         self.button_duplicates_warnings=gtk.Button(_("Duplicates Warnings"))
         self.button_duplicates_warnings.connect("clicked",self.check_duplicates_warnings)
 
         self.button_duplicates_errors=gtk.Button(_("Duplicates Errors"))
         self.button_duplicates_errors.connect("clicked",self.check_duplicates_errors)
-        bhbox=gtk.HBox()
-        bhbox.pack_start(self.button_duplicates_warnings,True,True)
-        bhbox.pack_start(self.button_duplicates_errors,True,True)
+        
+        button_table=gtk.Table(4,2,False)
         vbox.pack_start(scrolledwin,True,True,4)
-        vbox.pack_start(self.button_change,False,True,4)
-        vbox.pack_start(bhbox,False,True,4)
+        
+        sep=gtk.HSeparator()
+        button_table.attach(self.button_change,0,2,0,1,gtk.EXPAND|gtk.FILL,gtk.FILL,4,4)
+        button_table.attach(self.button_clear_shortcuts,0,1,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,4,4)
+        button_table.attach(self.button_default,1,2,1,2,gtk.EXPAND|gtk.FILL,gtk.FILL,4,4)
+        button_table.attach(self.button_duplicates_warnings,0,1,2,3,gtk.EXPAND|gtk.FILL,gtk.FILL,4,4)
+        button_table.attach(self.button_duplicates_errors,1,2,2,3,gtk.EXPAND|gtk.FILL,gtk.FILL,4,4)
+        button_table.attach(sep,0,2,3,4,gtk.EXPAND|gtk.FILL,gtk.EXPAND|gtk.FILL,4,4)
+        vbox.pack_start(button_table,False,True,4)
         
         hbox=gtk.HBox()
         self.ok_button=gtk.Button(None,gtk.STOCK_OK)
