@@ -238,7 +238,7 @@ class Score_Rules:
         try: xpn_article.lines
         except AttributeError: xpn_article.lines=0
 
-        xpost=xpn_article.xref.count(":")-1
+        xpost=xpn_article.xref.count(":")
 
         fields={"subject":xpn_article.subj,"from":xpn_article.from_name,"date":xpn_article.date,
                 "message-id":xpn_article.msgid,"references":xpn_article.ref,"age":age,"xref":xpn_article.xref,
@@ -268,7 +268,7 @@ class Score_Rules:
         if score<-9999: score=-9999
         return score
 
-    def apply_action_rules(self,xpn_article,group,watched,ignored):
+    def apply_action_rules(self,xpn_article,group):
         score=xpn_article.get_score()
         i=0
         time_now=mktime_tz(parsedate_tz(time.ctime()))
@@ -277,7 +277,7 @@ class Score_Rules:
         #compatibility check
         #there is no need here, it's has been already performed in apply_score_rules
         
-        xpost=xpn_article.xref.count(":")-1
+        xpost=xpn_article.xref.count(":")
 
         fields={"subject":xpn_article.subj,"from":xpn_article.from_name,"date":xpn_article.date,
                 "message-id":xpn_article.msgid,"references":xpn_article.ref,"age":age,"xref":xpn_article.xref,
@@ -295,7 +295,8 @@ class Score_Rules:
                         if action[0]=="!":
                             #this is an action
                             if action[1:]=="kill":
-                                xpn_article=None
+                                #xpn_article=None
+                                pass #need this to let reapply_rules work
                             elif action[1:]=="markread":
                                 xpn_article.is_read=True
                             elif action[1:]=="markunread":
@@ -311,19 +312,13 @@ class Score_Rules:
                             elif action[1:]=="watch":
                                 xpn_article.watch=True
                                 xpn_article.ignore=False
-                                watched.add(xpn_article.msgid)
-                                ignored.discard(xpn_article.msgid)
                             elif action[1:]=="ignore":
                                 xpn_article.watch=False
                                 xpn_article.ignore=True
                                 xpn_article.is_read=True
-                                watched.discard(xpn_article.msgid)
-                                ignored.add(xpn_article.msgid)
                             elif action[1:]=="unsetwatchignore":
                                 xpn_article.watch=False
                                 xpn_article.ignore=False
-                                watched.discard(xpn_article.msgid)
-                                ignored.discard(xpn_article.msgid)
                             elif action[1:].startswith("setcolor"):
                                 regex=re.compile("(^setcolor)\((([a-z]+)|(#\w+));(([a-z]+)|(#\w+))\)")
                                 matches=regex.match(action[1:])
@@ -331,7 +326,7 @@ class Score_Rules:
                                 xpn_article.bg_color=str(matches.groups()[4])
                             actions.append(action[1:])
             i=i+1
-        return xpn_article,actions,watched,ignored
+        return xpn_article,actions
        
     
     def __init__(self):
@@ -441,13 +436,8 @@ class Score_Win:
         self.score_rules.load_rules(lines)
         self.score_rules.lines=lines
         self.show_rules()
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            subscribed=[]
-        else:
-            subscribed=cPickle.load(f)
-            subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
+        subscribed=self.art_db.getSubscribed()
+        subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
         popdown=self.score_rules.raw_scopes
         for item in subscribed:
             if item not in popdown:
@@ -676,9 +666,10 @@ class Score_Win:
         else:
             self.color2_entry.set_text(color)
 
-    def __init__(self,score_rules):
+    def __init__(self,score_rules,main_win):
         self.score_rules=score_rules
         self.wdir=get_wdir()
+        self.art_db=main_win.art_db
         self.window=gtk.Window(gtk.WINDOW_TOPLEVEL)
         self.window.connect("delete_event",self.delete_event)
         self.window.connect("destroy",self.destroy)
@@ -761,13 +752,8 @@ class Score_Win:
         popdown=self.score_rules.raw_scopes
         if "[*]" not in popdown:
             popdown.insert(0,"[*]")
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            subscribed=[]
-        else:
-            subscribed=cPickle.load(f)
-            subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
+        subscribed=self.art_db.getSubscribed()
+        subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
         popdown=popdown+subscribed
         for item in popdown:
             self.scope_combo.append_text(item)
@@ -863,13 +849,8 @@ class Score_Win:
         popdown=self.score_rules.raw_scopes
         if "[*]" not in popdown:
             popdown.insert(0,"[*]")
-        try:
-            f=open(os.path.join(self.wdir,"groups_info/subscribed.dat"),"rb")
-        except IOError:
-            subscribed=[]
-        else:
-            subscribed=cPickle.load(f)
-            subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
+        subscribed=self.art_db.getSubscribed()
+        subscribed=["["+subscribed[i][0]+"]" for i in range(len(subscribed))]
         popdown=popdown+subscribed
         for item in popdown:
             self.action_scope_combo.append_text(item)
